@@ -1,8 +1,8 @@
 from .wog_abs import WoG
 import random
 from .utils import number_to_game, is_digit
-from .currency_converter import CurrencyConverter
-
+#from currency_converter import CurrencyConverter
+import currency_converter
 
 class CurrencyRGame(WoG):
 
@@ -40,7 +40,7 @@ class CurrencyRGame(WoG):
 
     @property
     def generated_number_from_USD_to_ILS(self):
-        c = CurrencyConverter()
+        c = currency_converter.CurrencyConverter()
         self.dolarToNis = c.convert(1, 'USD', 'ILS')
         self.dolarToNis = float(format(self.dolarToNis, '.2f'))
         self.current_currency_rate = self.usd_number * self.dolarToNis
