@@ -1,7 +1,7 @@
 
 from .mainGame import main
-#from .utils import get_user_name, welcome, load_game, number_to_game ,is_digit
-#from .Factory import Factory
+from .utils import get_user_name, welcome, load_game, number_to_game ,is_digit
+from .Factory import Factory
 from .wog_abs import WoG
 from .MemoryGame import MemoryGame
 from .GuessGame import GuessGame
